Class: Compactor
- Inherits:
-
Object
- Object
- Compactor
- Defined in:
- lib/active_record_scanner/compactor.rb
Instance Method Summary collapse
-
#deep_compact(n) ⇒ Object
This is really bad.
Instance Method Details
#deep_compact(n) ⇒ Object
This is really bad. It works for now but I’d really like to figure out a better way.
3 4 5 6 7 8 |
# File 'lib/active_record_scanner/compactor.rb', line 3 def deep_compact(n) 10.times do # won't work if we get a tree with >10 depth n = deep_compact_with_nesting(strip_nesting(n)) end n end |